using System;
using System.Text;

namespace at.jku.ssw.Analyse {
	/// <summary>
	/// Diese Klasse speichert die Informationen, die fr eine Klasse zutreffend sind.
	/// </summary>
	public class ClassInfo : MethodAvgInfo{
		public int iInheritanceDepth;	//Tiefe des Ableitungsbaumes
		public int iNumberOfChildren;	//Anzahl der Kinder-Klassen
										//Diese Informationen beziehen sich natrlich nur
										//auf Klassen, die im aktuellen File definiert sind.
										//System-Klassen werden nicht bercksichtigt.

		public String parentClass = "";	//Name der Vater-Klasse so wie er im Code steht

		public ClassInfo(String sName, int iLine, CodeInfo parent) : base(sName, iLine, parent) {
		}

		public override ClassInfo findClass(String sName) {
			if (sName == getFullName()) return this;
			else return base.findClass(sName);
		}

		public override void compute() {
			if (!hasComputed) {
				//in dieser Funktion wir die Ableitungstiefe und die Anzahl der Kinder
				//berechnet
				base.compute();
				if (parentClass == "") { //nicht abgeleitet -> Ableitungtiefe = 0
					iInheritanceDepth = 0;
					return;
				}

				ClassInfo clsTmp = findClassNFN(parentClass);
				if (clsTmp != null) {
					//Falls die VaterKlasse gefunden wurde, dann muss unbedingt zuerst
					//die compute-Methode dieser Vaterklasse aufgerufen werden, um zu verhindern,
					//falsche Werte im iInheritanceDepth-Feld zu haben
					clsTmp.compute();
					iInheritanceDepth = clsTmp.iInheritanceDepth + 1;
					clsTmp.iNumberOfChildren++;
				}
			}
		}

		public override String ToString(String sTab, bool bToDescend) {
			StringBuilder sb = new StringBuilder();
			sb.Append(sTab).Append("Class\n");
			sb.Append(sTab).Append("-----\n");
			sb.Append(base.ToString(sTab, bToDescend));
			sb.Append(sTab).AppendFormat("Parent Class:       {0}\n", parentClass);
			sb.Append(sTab).AppendFormat("Inheritance Depth:  {0}\n", iInheritanceDepth);
			sb.Append(sTab).AppendFormat("Number of Children: {0}\n", iNumberOfChildren);
			if (bToDescend)
				sb.Append(base.ToDescend(sTab));
			return sb.ToString();
		}

	}
}
